@@ -14,6 +14,8 @@
  * limitations under the License.
  */
 
+#define _POSIX_C_SOURCE 2 // for getopt
+
 #include <inttypes.h>
 #include <stdint.h>
 #include <stdio.h>
@@ -33,10 +35,13 @@
 
 #define PROGRAM_NAME	"corpus"
 
+int main_tokens(int argc, char * const argv[]);
+void usage_tokens(void);
 
-void usage_tokens(int status)
+
+void usage_tokens(void)
 {
-	const char **stems = stemmer_list();
+	const char **stems = corpus_stemmer_names();
 	int i;
 
 	printf("\
@@ -76,20 +81,18 @@ Options:\n\
 	} else {
 		printf("\n\t(none available)\n");
 	}
-
-	exit(status);
 }
 
 
 int main_tokens(int argc, char * const argv[])
 {
-	struct wordscan scan;
-	struct symtab symtab;
-	struct data data, val;
-	struct text name, text, word;
-	struct schema schema;
-	struct filebuf buf;
-	struct filebuf_iter it;
+	struct corpus_wordscan scan;
+	struct corpus_symtab symtab;
+	struct corpus_data data, val;
+	struct corpus_text name, text, word;
+	struct corpus_schema schema;
+	struct corpus_filebuf buf;
+	struct corpus_filebuf_iter it;
 	const char *output = NULL;
 	const char *stemmer = NULL;
 	const char *field, *input;
@@ -98,9 +101,10 @@ int main_tokens(int argc, char * const argv[])
 	int flags;
 	int ch, err, name_id, start, tokid, typid, zero;
 
-	flags = (TYPE_COMPAT | TYPE_CASEFOLD | TYPE_DASHFOLD
-			| TYPE_QUOTFOLD | TYPE_RMCC | TYPE_RMDI
-			| TYPE_RMWS);
+	flags = (CORPUS_TYPE_COMPAT | CORPUS_TYPE_CASEFOLD
+			| CORPUS_TYPE_DASHFOLD | CORPUS_TYPE_QUOTFOLD
+			| CORPUS_TYPE_RMCC | CORPUS_TYPE_RMDI
+			| CORPUS_TYPE_RMWS);
 
 	field = "text";
 
@@ -109,40 +113,41 @@ int main_tokens(int argc, char * const argv[])
 	while ((ch = getopt(argc, argv, "cdf:iko:qwxz")) != -1) {
 		switch (ch) {
 		case 'c':
-			flags &= ~TYPE_CASEFOLD;
+			flags &= ~CORPUS_TYPE_CASEFOLD;
 			break;
 		case 'd':
-			flags &= ~TYPE_DASHFOLD;
+			flags &= ~CORPUS_TYPE_DASHFOLD;
 			break;
 		case 'f':
 			field = optarg;
 			break;
 		case 'i':
-			flags &= ~TYPE_RMDI;
+			flags &= ~CORPUS_TYPE_RMDI;
 			break;
 		case 'k':
-			flags &= ~TYPE_COMPAT;
+			flags &= ~CORPUS_TYPE_COMPAT;
 			break;
 		case 'o':
 			output = optarg;
 			break;
 		case 'q':
-			flags &= ~TYPE_QUOTFOLD;
+			flags &= ~CORPUS_TYPE_QUOTFOLD;
 			break;
 		case 's':
 			stemmer = optarg;
 			break;
 		case 'w':
-			flags &= ~TYPE_RMWS;
+			flags &= ~CORPUS_TYPE_RMWS;
 			break;
 		case 'x':
-			flags &= ~TYPE_RMCC;
+			flags &= ~CORPUS_TYPE_RMCC;
 			break;
 		case 'z':
 			zero = 1;
 			break;
 		default:
-			usage_tokens(EXIT_FAILURE);
+			usage_tokens();
+			return EXIT_FAILURE;
 		}
 	}
 
@@ -151,10 +156,12 @@ int main_tokens(int argc, char * const argv[])
 
 	if (argc == 0) {
 		fprintf(stderr, "No input file specified.\n\n");
-		usage_tokens(EXIT_FAILURE);
+		usage_tokens();
+		return EXIT_FAILURE;
 	} else if (argc > 1) {
 		fprintf(stderr, "Too many input files specified.\n\n");
-		usage_tokens(EXIT_FAILURE);
+		usage_tokens();
+		return EXIT_FAILURE;
 	}
 
 	field_len = strlen(field);
@@ -165,48 +172,48 @@ int main_tokens(int argc, char * const argv[])
 
 	input = argv[0];
 
-	if (text_assign(&name, (uint8_t *)field, field_len, 0)) {
+	if (corpus_text_assign(&name, (const uint8_t *)field, field_len, 0)) {
 		fprintf(stderr, "Invalid field name (%s)\n", field);
-		exit(EXIT_FAILURE);
+		return EXIT_FAILURE;
 	}
 
-	if ((err = schema_init(&schema))) {
+	if ((err = corpus_schema_init(&schema))) {
 		goto error_schema;
 	}
 
-	if ((err = symtab_init(&symtab, flags, stemmer))) {
+	if ((err = corpus_symtab_init(&symtab, flags, stemmer))) {
 		goto error_symtab;
 	}
 
-	if ((err = filebuf_init(&buf, input))) {
+	if ((err = corpus_filebuf_init(&buf, input))) {
 		goto error_filebuf;
 	}
 
 	if (output) {
 		if (!(stream = fopen(output, "w"))) {
 			perror("Failed opening output file");
-			err = ERROR_OS;
+			err = CORPUS_ERROR_OS;
 			goto error_output;
 		}
 	} else {
 		stream = stdout;
 	}
 
-	if ((err = schema_name(&schema, &name, &name_id))) {
+	if ((err = corpus_schema_name(&schema, &name, &name_id))) {
 		goto error;
 	}
 
-	filebuf_iter_make(&it, &buf);
-	while (filebuf_iter_advance(&it)) {
-		if ((err = data_assign(&data, &schema, it.current.ptr,
-					it.current.size))) {
+	corpus_filebuf_iter_make(&it, &buf);
+	while (corpus_filebuf_iter_advance(&it)) {
+		if ((err = corpus_data_assign(&data, &schema, it.current.ptr,
+					      it.current.size))) {
 				goto error;
 		}
 
-		if ((err = data_field(&data, &schema, name_id, &val))) {
-			err = data_text(&data, &text);
+		if ((err = corpus_data_field(&data, &schema, name_id, &val))) {
+			err = corpus_data_text(&data, &text);
 		} else {
-			err = data_text(&val, &text);
+			err = corpus_data_text(&val, &text);
 		}
 
 		if (err) {
@@ -215,19 +222,20 @@ int main_tokens(int argc, char * const argv[])
 		}
 
 		fprintf(stream, "[");
-		wordscan_make(&scan, &text);
+		corpus_wordscan_make(&scan, &text);
 		start = 1;
-		while (wordscan_advance(&scan)) {
+		while (corpus_wordscan_advance(&scan)) {
 
-			if ((err = symtab_add_token(&symtab, &scan.current,
-							&tokid))) {
+			if ((err = corpus_symtab_add_token(&symtab,
+							   &scan.current,
+							   &tokid))) {
 				goto error;
 			}
 
 			typid = symtab.tokens[tokid].type_id;
 			word = symtab.types[typid].text;
 
-			if (TEXT_SIZE(&word) == 0 && !zero) {
+			if (CORPUS_TEXT_SIZE(&word) == 0 && !zero) {
 				continue;
 			}
 
@@ -237,7 +245,8 @@ int main_tokens(int argc, char * const argv[])
 				start = 0;
 			}
 
-			fprintf(stream, "\"%.*s\"", (int)TEXT_SIZE(&word),
+			fprintf(stream, "\"%.*s\"",
+				(int)CORPUS_TEXT_SIZE(&word),
 				(char *)word.ptr);
 		}
 		fprintf(stream, "]\n");
@@ -248,14 +257,14 @@ int main_tokens(int argc, char * const argv[])
 error:
 	if (output && fclose(stream) == EOF) {
 		perror("Failed closing output file");
-		err = ERROR_OS;
+		err = CORPUS_ERROR_OS;
 	}
 error_output:
-	filebuf_destroy(&buf);
+	corpus_filebuf_destroy(&buf);
 error_filebuf:
-	symtab_destroy(&symtab);
+	corpus_symtab_destroy(&symtab);
 error_symtab:
-	schema_destroy(&schema);
+	corpus_schema_destroy(&schema);
 error_schema:
 	if (err) {
 		fprintf(stderr, "An error occurred.\n");
