@@ -18,33 +18,48 @@
 #include <errno.h>
 #include <inttypes.h>
 #include <stdbool.h>
-#include <stdlib.h>
 #include <string.h>
 #include "../lib/libstemmer_c/include/libstemmer.h"
+#include "private/stopwords.h"
 #include "error.h"
+#include "memory.h"
 #include "text.h"
 #include "unicode.h"
-#include "xalloc.h"
 #include "token.h"
 
 
-static void typemap_clear_kind(struct typemap *map);
-static int typemap_set_kind(struct typemap *map, int kind);
+static void corpus_typemap_clear_kind(struct corpus_typemap *map);
+static int corpus_typemap_set_kind(struct corpus_typemap *map, int kind);
 
-static int typemap_reserve(struct typemap *map, size_t size);
-static int typemap_set_ascii(struct typemap *map, const struct text *tok);
-static int typemap_set_utf32(struct typemap *map, const uint32_t *ptr,
-			     const uint32_t *end);
-static int typemap_stem(struct typemap *map);
+static int corpus_typemap_reserve(struct corpus_typemap *map, size_t size);
+static int corpus_typemap_set_ascii(struct corpus_typemap *map,
+			     const struct corpus_text *tok);
+static int corpus_typemap_set_utf32(struct corpus_typemap *map,
+				    const uint32_t *ptr,
+				    const uint32_t *end);
+static int corpus_typemap_stem(struct corpus_typemap *map);
 
 
-const char **stemmer_list(void)
+const char **corpus_stemmer_names(void)
 {
 	return sb_stemmer_list();
 }
 
 
-int typemap_init(struct typemap *map, int kind, const char *stemmer)
+const uint8_t **corpus_stopwords(const char *name, int *lenptr)
+{
+	return stopwords(name, lenptr);
+}
+
+
+const char **corpus_stopword_names(void)
+{
+	return stopword_names();
+}
+
+
+int corpus_typemap_init(struct corpus_typemap *map, int kind,
+			const char *stemmer)
 {
 	int err;
 
@@ -53,12 +68,13 @@ int typemap_init(struct typemap *map, int kind, const char *stemmer)
 		map->stemmer = sb_stemmer_new(stemmer, "UTF_8");
 		if (!map->stemmer) {
 		       if (errno == ENOMEM) {
-			       err = ERROR_NOMEM;
-			       logmsg(err, "failed allocating stemmer");
+			       err = CORPUS_ERROR_NOMEM;
+			       corpus_log(err, "failed allocating stemmer");
 		       } else {
-				err = ERROR_INVAL;
-				logmsg(err, "unrecognized stemming algorithm"
-				       " (%s)", stemmer);
+				err = CORPUS_ERROR_INVAL;
+				corpus_log(err,
+					   "unrecognized stemming algorithm"
+					   " (%s)", stemmer);
 		       }
 		       goto out;
 		}
@@ -70,38 +86,38 @@ int typemap_init(struct typemap *map, int kind, const char *stemmer)
 	map->codes = NULL;
 	map->size_max = 0;
 
-	typemap_clear_kind(map);
-	err = typemap_set_kind(map, kind);
+	corpus_typemap_clear_kind(map);
+	err = corpus_typemap_set_kind(map, kind);
 out:
 	return err;
 }
 
 
-void typemap_destroy(struct typemap *map)
+void corpus_typemap_destroy(struct corpus_typemap *map)
 {
-	free(map->codes);
-	free(map->type.ptr);
+	corpus_free(map->codes);
+	corpus_free(map->type.ptr);
 	if (map->stemmer) {
 		sb_stemmer_delete(map->stemmer);
 	}
 }
 
 
-void typemap_clear_kind(struct typemap *map)
+void corpus_typemap_clear_kind(struct corpus_typemap *map)
 {
 	uint_fast8_t ch;
 
-	map->charmap_type = UDECOMP_NORMAL | UCASEFOLD_NONE;
+	map->charmap_type = CORPUS_UDECOMP_NORMAL | CORPUS_UCASEFOLD_NONE;
 
 	for (ch = 0; ch < 0x80; ch++) {
-		map->ascii_map[ch] = ch;
+		map->ascii_map[ch] = (int8_t)ch;
 	}
 
 	map->kind = 0;
 }
 
 
-int typemap_set_kind(struct typemap *map, int kind)
+int corpus_typemap_set_kind(struct corpus_typemap *map, int kind)
 {
 	int_fast8_t ch;
 
@@ -109,25 +125,25 @@ int typemap_set_kind(struct typemap *map, int kind)
 		return 0;
 	}
 
-	typemap_clear_kind(map);
+	corpus_typemap_clear_kind(map);
 
-	if (kind & TYPE_COMPAT) {
-		map->charmap_type = UDECOMP_ALL;
+	if (kind & CORPUS_TYPE_COMPAT) {
+		map->charmap_type = CORPUS_UDECOMP_ALL;
 	}
 
-	if (kind & TYPE_CASEFOLD) {
+	if (kind & CORPUS_TYPE_CASEFOLD) {
 		for (ch = 'A'; ch <= 'Z'; ch++) {
 			map->ascii_map[ch] = ch + ('a' - 'A');
 		}
 
-		map->charmap_type |= UCASEFOLD_ALL;
+		map->charmap_type |= CORPUS_UCASEFOLD_ALL;
 	}
 
-	if (kind & TYPE_QUOTFOLD) {
+	if (kind & CORPUS_TYPE_QUOTFOLD) {
 		map->ascii_map['"'] = '\'';
 	}
 
-	if (kind & TYPE_RMCC) {
+	if (kind & CORPUS_TYPE_RMCC) {
 		for (ch = 0x00; ch <= 0x08; ch++) {
 			map->ascii_map[ch] = -1;
 		}
@@ -137,7 +153,7 @@ int typemap_set_kind(struct typemap *map, int kind)
 		map->ascii_map[0x7F] = -1;
 	}
 
-	if (kind & TYPE_RMWS) {
+	if (kind & CORPUS_TYPE_RMWS) {
 		for (ch = 0x09; ch <= 0x0D; ch++) {
 			map->ascii_map[ch] = -1;
 		}
@@ -150,7 +166,7 @@ int typemap_set_kind(struct typemap *map, int kind)
 }
 
 
-int typemap_reserve(struct typemap *map, size_t size)
+int corpus_typemap_reserve(struct corpus_typemap *map, size_t size)
 {
 	uint8_t *ptr = map->type.ptr;
 	uint32_t *codes = map->codes;
@@ -160,12 +176,13 @@ int typemap_reserve(struct typemap *map, size_t size)
 		return 0;
 	}
 
-	if (!(ptr = xrealloc(ptr, size))) {
+	if (!(ptr = corpus_realloc(ptr, size))) {
 		goto error_nomem;
 	}
 	map->type.ptr = ptr;
 
-	if (!(codes = xrealloc(codes, size * UNICODE_DECOMP_MAX))) {
+	if (!(codes = corpus_realloc(codes,
+				     size * CORPUS_UNICODE_DECOMP_MAX))) {
 		goto error_nomem;
 	}
 	map->codes = codes;
@@ -174,55 +191,57 @@ int typemap_reserve(struct typemap *map, size_t size)
 	return 0;
 
 error_nomem:
-	err = ERROR_NOMEM;
-	logmsg(err, "failed allocating type map buffer");
+	err = CORPUS_ERROR_NOMEM;
+	corpus_log(err, "failed allocating type map buffer");
 	return err;
 }
 
 
-int typemap_set(struct typemap *map, const struct text *tok)
+int corpus_typemap_set(struct corpus_typemap *map,
+		       const struct corpus_text *tok)
 {
-	struct text_iter it;
-	size_t size = TEXT_SIZE(tok);
+	struct corpus_text_iter it;
+	size_t size = CORPUS_TEXT_SIZE(tok);
 	uint32_t *dst;
 	int err;
 
-	if (TEXT_IS_ASCII(tok)) {
-		if ((err = typemap_set_ascii(map, tok))) {
+	if (CORPUS_TEXT_IS_ASCII(tok)) {
+		if ((err = corpus_typemap_set_ascii(map, tok))) {
 			goto error;
 		}
 		goto stem;
 	}
 
-	if ((err = typemap_reserve(map, size + 1))) {
+	if ((err = corpus_typemap_reserve(map, size + 1))) {
 		goto error;
 	}
 
 	dst = map->codes;
-	text_iter_make(&it, tok);
-	while (text_iter_advance(&it)) {
-		unicode_map(map->charmap_type, it.current, &dst);
+	corpus_text_iter_make(&it, tok);
+	while (corpus_text_iter_advance(&it)) {
+		corpus_unicode_map(map->charmap_type, it.current, &dst);
 	}
 
-	size = dst - map->codes;
-	unicode_order(map->codes, size);
-	unicode_compose(map->codes, &size);
+	size = (size_t)(dst - map->codes);
+	corpus_unicode_order(map->codes, size);
+	corpus_unicode_compose(map->codes, &size);
 
-	if ((err = typemap_set_utf32(map, map->codes, map->codes + size))) {
+	if ((err = corpus_typemap_set_utf32(map, map->codes,
+					    map->codes + size))) {
 		goto error;
 	}
 
 stem:
-	err = typemap_stem(map);
+	err = corpus_typemap_stem(map);
 	return err;
 
 error:
-	logmsg(err, "failed normalizing token");
+	corpus_log(err, "failed normalizing token");
 	return err;
 }
 
 
-int typemap_stem(struct typemap *map)
+int corpus_typemap_stem(struct corpus_typemap *map)
 {
 	size_t size;
 	const uint8_t *buf;
@@ -232,21 +251,22 @@ int typemap_stem(struct typemap *map)
 		return 0;
 	}
 
-	size = TEXT_SIZE(&map->type);
+	size = CORPUS_TEXT_SIZE(&map->type);
 
 	if (size >= INT_MAX) {
-		err = ERROR_OVERFLOW;
-		logmsg(err, "type size (%"PRIu64" bytes)"
-		       " exceeds maximum (%d)", (uint64_t)size, INT_MAX - 1);
+		err = CORPUS_ERROR_OVERFLOW;
+		corpus_log(err, "type size (%"PRIu64" bytes)"
+			   " exceeds maximum (%d)",
+			   (uint64_t)size, INT_MAX - 1);
 		goto out;
 	}
 
 	buf = (const uint8_t *)sb_stemmer_stem(map->stemmer, map->type.ptr,
 					       (int)size);
 	if (buf == NULL) {
-		err = ERROR_NOMEM;
-		logmsg(err, "failed allocating memory to stem word"
-		       " of size %"PRIu64" bytes", (uint64_t)size);
+		err = CORPUS_ERROR_NOMEM;
+		corpus_log(err, "failed allocating memory to stem word"
+			   " of size %"PRIu64" bytes", (uint64_t)size);
 		goto out;
 	}
 
@@ -256,8 +276,8 @@ int typemap_stem(struct typemap *map)
 	map->type.ptr[size] = '\0';
 
 	// keep old utf8 bit, but update to new size
-	map->type.attr &= ~TEXT_SIZE_MASK;
-	map->type.attr |= TEXT_SIZE_MASK & size;
+	map->type.attr &= ~CORPUS_TEXT_SIZE_MASK;
+	map->type.attr |= CORPUS_TEXT_SIZE_MASK & size;
 	err = 0;
 
 out:
@@ -265,14 +285,14 @@ out:
 }
 
 
-int typemap_set_utf32(struct typemap *map, const uint32_t *ptr,
-		     const uint32_t *end)
+int corpus_typemap_set_utf32(struct corpus_typemap *map, const uint32_t *ptr,
+			     const uint32_t *end)
 {
-	bool fold_dash = map->kind & TYPE_DASHFOLD;
-	bool fold_quot = map->kind & TYPE_QUOTFOLD;
-	bool rm_cc = map->kind & TYPE_RMCC;
-	bool rm_di = map->kind & TYPE_RMDI;
-	bool rm_ws = map->kind & TYPE_RMWS;
+	bool fold_dash = map->kind & CORPUS_TYPE_DASHFOLD;
+	bool fold_quot = map->kind & CORPUS_TYPE_QUOTFOLD;
+	bool rm_cc = map->kind & CORPUS_TYPE_RMCC;
+	bool rm_di = map->kind & CORPUS_TYPE_RMDI;
+	bool rm_ws = map->kind & CORPUS_TYPE_RMWS;
 	uint8_t *dst = map->type.ptr;
 	uint32_t code;
 	int8_t ch;
@@ -486,37 +506,39 @@ int typemap_set_utf32(struct typemap *map, const uint32_t *ptr,
 		if (code >= 0x80) {
 			utf8 = true;
 		}
-		encode_utf8(code, &dst);
+		corpus_encode_utf8(code, &dst);
 	}
 
 	*dst = '\0'; // not necessary, but helps with debugging
-	map->type.attr = TEXT_SIZE_MASK & (dst - map->type.ptr);
+	map->type.attr = (CORPUS_TEXT_SIZE_MASK
+			  & ((size_t)(dst - map->type.ptr)));
 	if (utf8) {
-		map->type.attr |= TEXT_UTF8_BIT;
+		map->type.attr |= CORPUS_TEXT_UTF8_BIT;
 	}
 
 	return 0;
 }
 
 
-int typemap_set_ascii(struct typemap *map, const struct text *tok)
+int corpus_typemap_set_ascii(struct corpus_typemap *map,
+			     const struct corpus_text *tok)
 {
-	struct text_iter it;
-	size_t size = TEXT_SIZE(tok);
+	struct corpus_text_iter it;
+	size_t size = CORPUS_TEXT_SIZE(tok);
 	int8_t ch;
 	uint8_t *dst;
 	int err;
 
-	assert(TEXT_IS_ASCII(tok));
+	assert(CORPUS_TEXT_IS_ASCII(tok));
 
-	if ((err = typemap_reserve(map, size + 1))) {
+	if ((err = corpus_typemap_reserve(map, size + 1))) {
 		goto error;
 	}
 
 	dst = map->type.ptr;
 
-	text_iter_make(&it, tok);
-	while (text_iter_advance(&it)) {
+	corpus_text_iter_make(&it, tok);
+	while (corpus_text_iter_advance(&it)) {
 		ch = map->ascii_map[it.current];
 		if (ch >= 0) {
 			*dst++ = (uint8_t)ch;
@@ -524,20 +546,21 @@ int typemap_set_ascii(struct typemap *map, const struct text *tok)
 	}
 
 	*dst = '\0'; // not necessary, but helps with debugging
-	map->type.attr = TEXT_SIZE_MASK & (dst - map->type.ptr);
+	map->type.attr = (CORPUS_TEXT_SIZE_MASK
+			  & ((size_t)(dst - map->type.ptr)));
 	return 0;
 
 error:
-	logmsg(err, "failed normalizing token");
+	corpus_log(err, "failed normalizing token");
 	return err;
 }
 
 
 // Dan Bernstein's djb2 XOR hash: http://www.cse.yorku.ca/~oz/hash.html
-unsigned token_hash(const struct text *tok)
+unsigned corpus_token_hash(const struct corpus_text *tok)
 {
 	const uint8_t *ptr = tok->ptr;
-	const uint8_t *end = ptr + TEXT_SIZE(tok);
+	const uint8_t *end = ptr + CORPUS_TEXT_SIZE(tok);
 	unsigned hash = 5381;
 	uint_fast8_t ch;
 
@@ -550,17 +573,20 @@ unsigned token_hash(const struct text *tok)
 }
 
 
-int token_equals(const struct text *t1, const struct text *t2)
+int corpus_token_equals(const struct corpus_text *t1,
+			const struct corpus_text *t2)
 {
-	return ((t1->attr & ~TEXT_UTF8_BIT) == (t2->attr & ~TEXT_UTF8_BIT)
-			&& !memcmp(t1->ptr, t2->ptr, TEXT_SIZE(t2)));
+	return ((t1->attr & ~CORPUS_TEXT_UTF8_BIT)
+			== (t2->attr & ~CORPUS_TEXT_UTF8_BIT)
+		&& !memcmp(t1->ptr, t2->ptr, CORPUS_TEXT_SIZE(t2)));
 }
 
 
-int compare_type(const struct text *typ1, const struct text *typ2)
+int corpus_compare_type(const struct corpus_text *typ1,
+			const struct corpus_text *typ2)
 {
-	size_t n1 = TEXT_SIZE(typ1);
-	size_t n2 = TEXT_SIZE(typ2);
+	size_t n1 = CORPUS_TEXT_SIZE(typ1);
+	size_t n2 = CORPUS_TEXT_SIZE(typ2);
 	size_t n = (n1 < n2) ? n1 : n2;
 	return memcmp(typ1->ptr, typ2->ptr, n);
 }
